@@ -127,7 +127,7 @@ class PropertyRemapping:
 
     def _get_dynamo_item_from_table(self, table_name, item_id):
         table_name_with_environment = self.table_helper.get_table_name(table_name)
-        return get_dynamo_item(table_name_with_environment, item_id)
+        return get_dynamo_item(table_name_with_environment, item_id, dynamodb_helper=self.dynamo_helper)
 
     def get_offer(self, offer_id):
         """
